---
title: UK Biobank Pharma Proteomics Project (UKB-PPP) (EUR)
---

The UKB-PPP is a collaboration between the UK Biobank (UKB) and thirteen biopharmaceutical companies characterising the plasma proteomic profiles of 54,219 UKB participants.

The original data is available here: https://www.synapse.org/Synapse:syn51364943/wiki/622119.
The associated paper is https://www.nature.com/articles/s41586-023-06592-6.
